@@ -77,7 +77,14 @@ class Edk2PrEval(Edk2MultiPkgAwareInvocable):
         return "PREVALLOG"
 
     def Go(self):
-        self.edk2_path_obj = path_utilities.Edk2Path(self.GetWorkspaceRoot(), self.GetPackagesPath())
+
+        # create path obj for resolving paths.  Since PR eval is run early to determine if a build is
+        # impacted by the changes of a PR we must ignore any packages path that are not valid due to
+        # not having their submodule or folder populated.
+        # A packages path is ok to drop for this because if it isn't populated it is assumed outside
+        # the repository and thus will not trigger the build.
+        self.edk2_path_obj = path_utilities.Edk2Path(
+            self.GetWorkspaceRoot(), self.GetPackagesPath(), error_on_invalid_pp=False)
         self.logger = logging.getLogger("edk2_pr_eval")
         actualPackagesDict = self.get_packages_to_build(self.requested_package_list)
 
@@ -205,6 +212,8 @@ class Edk2PrEval(Edk2MultiPkgAwareInvocable):
             dsc = DscParser()
             dsc.SetBaseAbsPath(self.edk2_path_obj.WorkspacePath)
             dsc.SetPackagePaths(self.edk2_path_obj.PackagePathList)
+            # given that PR eval runs before dependencies are downloaded we must tolerate errors
+            dsc.SetNoFailMode()
             dsc.SetInputVars(PlatformDscInfo[1])
             dsc.ParseFile(PlatformDscInfo[0])
             allinfs = dsc.OtherMods + dsc.ThreeMods + dsc.SixMods + dsc.Libs  # get list of all INF files
@@ -326,6 +335,10 @@ class Edk2PrEval(Edk2MultiPkgAwareInvocable):
         fp = filepath.replace("\\", "/")  # make consistant for easy compare
 
         self.logger.debug("Is public: " + fp)
+
+        if filepath.lower().endswith(".dec"):  # if DEC file then it is public
+            return True
+
         try:
             pkg = self.edk2_path_obj.GetContainingPackage(os.path.abspath(filepath))
         except Exception as e:
@@ -343,8 +356,8 @@ class Edk2PrEval(Edk2MultiPkgAwareInvocable):
         if dec is None:
             return False
 
-        for includepath in dec.IncludePaths:
-            if (pkg + "/" + includepath) in filepath:
+        for includepath in dec.IncludePaths:  # if in the include path of a package then it is public
+            if (pkg + "/" + includepath + "/") in filepath:
                 return True
 
         return False
